.. _running:

Running dhcpcanon
==================

    dhcpca.py [-h] [-d] [-l LEASE] [-v] [interface]

positional arguments:
  interface interface to configure with DHCP

optional arguments:

  -h, --help show this help message and exit

  -d, --debug debug

  -l LEASE, --lease custom lease time

  -v, --version version
